@@ -1,7 +1,8 @@
-from PyObjCTools.TestSupport import *
+import array
 
 import libdispatch
-import array
+from PyObjCTools.TestSupport import TestCase
+import objc
 
 
 class TestOnceAPI(TestCase):
@@ -16,7 +17,9 @@ class TestOnceAPI(TestCase):
         self.assertArgHasType(
             libdispatch.dispatch_once_f, 0, objc._C_INOUT + objc._C_PTR + objc._C_LNG
         )
-        self.assertArgHasType(libdispatch.dispatch_once_f, 1, objc._C_PTR + objc._C_VOID)
+        self.assertArgHasType(
+            libdispatch.dispatch_once_f, 1, objc._C_PTR + objc._C_VOID
+        )
         self.assertArgIsFunction(libdispatch.dispatch_once_f, 2, b"v^v", 0)
 
 
@@ -25,23 +28,19 @@ class TestOnceUsage(TestCase):
         pred = 0
         record = []
 
-        def callable():
+        def function():
             record.append(None)
 
-        self.assertRaises(TypeError, libdispatch.dispatch_once, pred, callable)
+        self.assertRaises(TypeError, libdispatch.dispatch_once, pred, function)
 
     def test_arrayvar(self):
         pred = array.array("l", [0])
         record = []
 
-        def callable():
+        def function():
             record.append(None)
 
-        libdispatch.dispatch_once(pred, callable)
-        libdispatch.dispatch_once(pred, callable)
+        libdispatch.dispatch_once(pred, function)
+        libdispatch.dispatch_once(pred, function)
 
         self.assertEqual(record, [None])
-
-
-if __name__ == "__main__":
-    main()
